==> haskell-dbus-hslogger-0.1.0.1-642-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-dbus-hslogger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dbus-hslogger
version:              0.1.0.1
visibility:           public
id:                   dbus-hslogger-0.1.0.1-3pEpRnDRYbJ13sYdIrOhv4
key:                  dbus-hslogger-0.1.0.1-3pEpRnDRYbJ13sYdIrOhv4
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/dbus-hslogger#readme
synopsis:             Expose a dbus server to control hslogger
description:
    Please see the README on Github at <https://github.com/IvanMalison/dbus-hslogger#readme>

category:             System
abi:                  44ee87671e41c59dbbdd6ba94f2ce3ca
exposed:              True
exposed-modules:      System.Log.DBus.Client System.Log.DBus.Server
hidden-modules:       Paths_dbus_hslogger
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dbus-hslogger-0.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dbus-hslogger-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dbus-hslogger-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dbus-hslogger
hs-libraries:         HSdbus-hslogger-0.1.0.1-3pEpRnDRYbJ13sYdIrOhv4
depends:
    base-4.17.2.1 dbus-1.3.3-DxwQecE0J4QHGHdMDtxYGB
    hslogger-1.3.2.0-5UzjE3rtE0cIibzskwqOPp

haddock-interfaces:
    /usr/share/doc/haskell-dbus-hslogger/html/dbus-hslogger.haddock

haddock-html:         /usr/share/doc/haskell-dbus-hslogger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dbus-hslogger-0.1.0.1-663-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-dbus-hslogger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dbus-hslogger
version:              0.1.0.1
visibility:           public
id:                   dbus-hslogger-0.1.0.1-7oN5hNkaxrz7NPRdfwtKue
key:                  dbus-hslogger-0.1.0.1-7oN5hNkaxrz7NPRdfwtKue
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/dbus-hslogger#readme
synopsis:             Expose a dbus server to control hslogger
description:
    Please see the README on Github at <https://github.com/IvanMalison/dbus-hslogger#readme>

category:             System
abi:                  95402704a37944edf372af5937855754
exposed:              True
exposed-modules:      System.Log.DBus.Client System.Log.DBus.Server
hidden-modules:       Paths_dbus_hslogger
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dbus-hslogger-0.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dbus-hslogger-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dbus-hslogger-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dbus-hslogger
hs-libraries:         HSdbus-hslogger-0.1.0.1-7oN5hNkaxrz7NPRdfwtKue
depends:
    base-4.17.2.1 dbus-1.3.3-LpDQHaNyiML1MRcclv9sum
    hslogger-1.3.2.0-20ZBQm4ZKyVCpCr1LdKap5

haddock-interfaces:
    /usr/share/doc/haskell-dbus-hslogger/html/dbus-hslogger.haddock

haddock-html:         /usr/share/doc/haskell-dbus-hslogger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
